<?php
/* Set constant path to the plugin directory */
define( 'CHARVI_DIR', trailingslashit( plugin_dir_path( __FILE__ ) ) );

/* Set the constant path to the plugin directory URI */
define( 'CHARVI_URI', trailingslashit( plugin_dir_url( __FILE__ ) ) );

/**
 * dtr_charvi_core class.
 */
if( ! class_exists( 'dtr_charvi_core' ) ) {
class dtr_charvi_core {

	/**
	 * Plugin version, used for cache-busting of style and script file references.
	 *
	 * @since   1.0.0
	 */
	protected $version = '1.0.1';

	/**
	 * Unique identifier for your plugin.
	 *
	 * Use this value (not the variable name) as the text domain when internationalizing strings of text. It should
	 * match the Text Domain file header in the main plugin file.
	 *
	 * @since   1.0.0
	 */
	protected $plugin_slug = 'charvi';

	/**
	 * Instance of this class.
	 *
     * @since   1.0.0
	 */
	protected static $instance = null;

	/**
	 * Slug of the plugin screen.
	 *
	 * @since   1.0.0
	 */
	protected $plugin_screen_hook_suffix = null;

	/**
	 * Initialize the plugin
	 *
	 * @since   1.0.0
	 */
	private function __construct() {
		
		// Image Resizer
		require_once( CHARVI_DIR . 'includes/aq_resizer.php' );
		
		// Make shortcodes available
		require_once( CHARVI_DIR . 'includes/shortcodes.php' );
		
		// Make cpt available
		require_once( CHARVI_DIR . 'includes/cpt.php' );

		// Meta Boxes
		if ( file_exists(  CHARVI_DIR . '/includes/meta-box/init.php' ) ) {
			require_once  CHARVI_DIR . '/includes/meta-box/init.php';
		} 
		require_once ( CHARVI_DIR . '/includes/metabox-config.php' );

		add_filter( 'the_content', array( $this, 'dtr_charvi_remove_sc_wrapping_spaces' ) );
		
		// init process for button control
		add_action( 'init', array( &$this, 'init' ) );
	 	   
		// Add scripts and styles
		add_action( 'wp_enqueue_scripts', array( &$this, 'dtr_charvi_add_scripts' ) );
		add_action( 'wp_enqueue_scripts', array( &$this, 'dtr_charvi_add_styles' ) );
		add_action( 'admin_enqueue_scripts', array( &$this, 'load_admin_style' )  );
	
		// Load plugin text domain
		add_action( 'init', array( $this, 'load_plugin_textdomain' ) );
	}

	/**
	 * Return an instance of this class.
	 *
	 * @since   1.0.0
	 */
	public static function get_instance() {

		// If the single instance hasn't been set, set it now.
		if ( null == self::$instance ) {
			self::$instance = new self;
		}

		return self::$instance;
	}

	/**
	 * Load the plugin text domain for translation.
	 *
	 * @since   1.0.0
	 */
	public function load_plugin_textdomain() {

		$domain = $this->plugin_slug;
		$locale = apply_filters( 'plugin_locale', get_locale(), $domain );

		load_textdomain( $domain, WP_LANG_DIR . '/' . $domain . '/' . $domain . '-' . $locale . '.mo' );
		load_plugin_textdomain( $domain, FALSE, dirname( plugin_basename( __FILE__ ) ) . '/lang/' );
	}

	/**
	 * Registers TinyMCE rich editor buttons
	 *
	 * @since   1.0.0
	 */
	 function init() {
		// Don't bother doing this stuff if the current user lacks permissions
		if ( ! current_user_can('edit_posts') && ! current_user_can('edit_pages') )
			return;
			
	 
		// Add only in Rich Editor mode
		if ( get_user_option('rich_editing') == 'true') {
			// filter the tinyMCE buttons and add our own
			add_filter( 'mce_external_plugins', array( &$this, 'dtr_charvi_add_tinymce_plugin' ) );
			add_filter( 'mce_buttons_3', array( &$this, 'dtr_charvi_register_tinymce_buttons' ) );
		}
	}
	
	// Add tinymce
	function dtr_charvi_add_tinymce_plugin($plugin_array) {
    	$plugin_array['dtrshortcodes'] = plugins_url( 'includes/tinymce.js', __FILE__ ); 
    	return $plugin_array;
	}

	// Register Buttons
	function dtr_charvi_register_tinymce_buttons($buttons) {
	   array_push($buttons, "dtr_layout", "dtr_icon", "dtr_button", "dtr_elements", "dtr_typography");
	   return $buttons;
	}
	
	// Remove spaces wrapping shortcodes
	function dtr_charvi_remove_sc_wrapping_spaces( $content ) {
		$array = array(
			'<p>[' => '[',
			']</p>' => ']',
			']<br>' => ']'
		);
		$content = strtr( $content, $array );
		return $content;
	}

	/**
	 *  Enqueue Javascript files
	 *
	 * @since   1.0.0
     */
	function dtr_charvi_add_scripts() { 

	} // dtr_charvi_add_scripts

	/**
     * Enqueue Style sheets
	 *
	 * @since   1.0.0
     */
	function dtr_charvi_add_styles() { 
		
	} // dtr_charvi_add_styles
	
	
	function load_admin_style() {
        wp_register_style( 'tinymce-custom-style', CHARVI_URI . 'assets/css/tinymce.css' );
		wp_enqueue_style( 'tinymce-custom-style' );
	 	wp_enqueue_script( 'wp-color-picker' ); // the wp-color-picker javascript file
   		wp_enqueue_style( 'wp-color-picker' ); // the wp-color-picker css file
     }

 } 
} // class dtr_charvi_core

/**
 * Register font size tinymce button
 *
 */
if ( ! function_exists( 'dtr_charvi_tinymce_font_buttons' ) ) {
	function dtr_charvi_tinymce_font_buttons( $buttons ) {
		array_unshift( $buttons, 'fontsizeselect' ); // Add Font Size Select
		return $buttons;
	}
}
add_filter( 'mce_buttons_2', 'dtr_charvi_tinymce_font_buttons' );

// Custom font sizes
if ( ! function_exists( 'dtr_charvi_tinymce_text_sizes' ) ) {
	function dtr_charvi_tinymce_text_sizes( $initArray ){
		$initArray['fontsize_formats'] = "9px 10px 12px 13px 14px 16px 18px 20px 21px 22px 24px 26px 28px 30px";
		return $initArray;
	}
}
add_filter( 'tiny_mce_before_init', 'dtr_charvi_tinymce_text_sizes' );

// Shortcodes in excerpt
add_filter('get_the_excerpt', 'shortcode_unautop');
add_filter('get_the_excerpt', 'do_shortcode');

// Shortcodes in widget
add_filter('widget_text','do_shortcode');

/**
 * Author bios custom fields
 */
if ( ! function_exists( 'charvi_modified_authorbio_fields' ) ) :
function charvi_modified_authorbio_fields( $contact_methods ){
	$contact_methods['charvi_twitter'] 	= esc_html__('Twitter URL', 'charvi'); 
	$contact_methods['charvi_facebook']	= esc_html__('Facebook URL', 'charvi');
	$contact_methods['charvi_instagram']	= esc_html__('Instagram URL', 'charvi');
	$contact_methods['charvi_pinterest']	= esc_html__('Pinterest URL', 'charvi'); 
	$contact_methods['charvi_linkedin']	= esc_html__('Linkedin URL', 'charvi'); 
	$contact_methods['charvi_mail']		= esc_html__('Mail to URL', 'charvi');
	return $contact_methods;
}
endif; 
add_filter('user_contactmethods', 'charvi_modified_authorbio_fields');
// charvi_modified_authorbio_fields

/**
 * Code in Header
 */ 
if ( !function_exists('charvi_get_header_code') ) {
	add_action('wp_head', 'charvi_get_header_code', 1);
	function charvi_get_header_code() {
		echo get_theme_mod ( 'charvi_header_code' );
	} 
} 

/**
 * Post Social share 
 */
// Post Social share hook
function charvi_social_share_hook() {
	do_action( 'charvi_social_share_hook' );
}
add_action( 'charvi_social_share_hook', 'charvi_default_social_share_hook' );

if( ! function_exists( 'charvi_default_social_share_hook' ) ) {
	function charvi_default_social_share_hook() {
		charvi_social_share();
	}
}
// Social Share
if ( ! function_exists('charvi_social_share') ) {
	function charvi_social_share() {
	
	// return if post password protected or share disabled
	if ( false == get_theme_mod( 'charvi_social_share_enable', true ) ) {
		return;
	}
	// vars
	$twitter_handle = $style = '';
	$post_id 		= get_the_ID();
	$url      		= get_permalink( $post_id );
	$title    		= get_the_title();
	$twitter_handle	= get_theme_mod( 'charvi_twitter_handle_text', '' );
	$excerpt 		= get_the_excerpt();
	$style 			= get_theme_mod( 'charvi_social_share_style', 'dtr-social-default' ); 
	?>
	<div class="dtr-social-share <?php echo esc_attr ( $style ) ?> clearfix">
	<span class="dtr-social-share-title">Share</span>
		<ul class="dtr-social-list">
			<?php if ( true == get_theme_mod( 'charvi_twitter_share_enable', true ) ) { ?>
			<li> <a href="https://twitter.com/share?text=<?php echo rawurlencode( $title ); ?>&amp;url=<?php echo rawurlencode( esc_url( $url ) ); ?><?php if ( $twitter_handle ) echo '&amp;via='. esc_attr( $twitter_handle ); ?>" title="<?php esc_html_e( 'Twitter', 'charvi' ); ?>" onclick="javascript:window.open(this.href, '', 'menubar=no,toolbar=no,resizable=yes,scrollbars=yes,height=500,width=500');return false;" class="dtr-twitter" data-placement="top" data-toggle="tooltip"> </a> </li>
			<?php } ?>
			<?php if ( true == get_theme_mod( 'charvi_facebook_share_enable', true ) ) { ?>
			<li> <a href="https://www.facebook.com/sharer/sharer.php?u=<?php echo rawurlencode( esc_url( $url ) ); ?>" title="<?php esc_html_e( 'Facebook', 'charvi' ); ?>" onclick="javascript:window.open(this.href, '', 'menubar=no,toolbar=no,resizable=yes,scrollbars=yes,height=500,width=500');return false;" class="dtr-facebook" data-placement="top" data-toggle="tooltip"> </a> </li>
			<?php } ?>
			<?php if ( true == get_theme_mod( 'charvi_pinterest_share_enable', true ) ) { ?>
			<li> <a href="https://www.pinterest.com/pin/create/button/?url=<?php echo rawurlencode( esc_url( $url ) ); ?>&amp;media=<?php echo wp_get_attachment_url( get_post_thumbnail_id( $post_id ) ); ?>&amp;description=<?php echo rawurlencode( $title ); ?>" title="<?php esc_html_e( 'Pinterest', 'charvi' ); ?>" onclick="javascript:window.open(this.href, '', 'menubar=no,toolbar=no,resizable=yes,scrollbars=yes,height=500,width=500');return false;" class="dtr-pinterest" data-placement="top" data-toggle="tooltip"></a> </li>
			<?php } ?>
			<?php if ( true == get_theme_mod( 'charvi_googleplus_share_enable', true ) ) { ?>
			<li> <a href="https://plus.google.com/share?url=<?php echo rawurlencode( esc_url( $url ) ); ?>" title="<?php esc_html_e( 'Google+', 'charvi' ); ?>" onclick="javascript:window.open(this.href, '', 'menubar=no,toolbar=no,resizable=yes,scrollbars=yes,height=500,width=500');return false;" class="dtr-googleplus" data-placement="top" data-toggle="tooltip"> </a> </li>
			<?php } ?>
			<?php if ( true == get_theme_mod( 'charvi_linkedin_share_enable', true ) ) { ?>
			<li> <a href="https://www.linkedin.com/shareArticle?mini=true&amp;url=<?php echo rawurlencode( esc_url( $url ) ); ?>&amp;title=<?php echo rawurlencode( $title ); ?>&amp;summary=<?php echo rawurlencode( $excerpt ); ?>&amp;source=<?php echo esc_url( home_url( '/' ) ); ?>" title="<?php esc_html_e( 'LinkedIn', 'charvi' ); ?>" onclick="javascript:window.open(this.href, '', 'menubar=no,toolbar=no,resizable=yes,scrollbars=yes,height=500,width=500');return false;" class="dtr-linkedin" data-placement="top" data-toggle="tooltip"> </a> </li>
			<?php } ?>
		</ul>
	</div>
<?php	}
} // charvi_social_share

/**
 * Social share band above footer
 */
// Social share band hook
function charvi_social_band_hook() {
	do_action( 'charvi_social_band_hook' );
}
add_action( 'charvi_social_band_hook', 'charvi_default_social_band_hook' );

if( ! function_exists( 'charvi_default_social_band_hook' ) ) {
	function charvi_default_social_band_hook() {
		charvi_social_band();
	}
}
// Social Share band
if ( ! function_exists('charvi_social_band') ) {
	function charvi_social_band() {
	
	// return if share band disabled
	if ( 'hide' == get_theme_mod( 'charvi_social_share_band_enable', 'show' ) ) {
		return;
	}
	
	$twitter_link			= get_theme_mod( 'charvi_twitter_link', '#' );
	$pinterest_link			= get_theme_mod( 'charvi_pinterest_link', '#' );
	$facebook_link			= get_theme_mod( 'charvi_facebook_link', '#' );
	$googleplus_link		= get_theme_mod( 'charvi_googleplus_link', '#' );
	$linkedin_link			= get_theme_mod( 'charvi_linkedin_link', '#' );
	$youtube_link			= get_theme_mod( 'charvi_youtube_link', '#' );
	$soundcloud_link		= get_theme_mod( 'charvi_soundcloud_link', '#' );
	$instagram_link			= get_theme_mod( 'charvi_instagram_link', '#' );
	$vimeo_link				= get_theme_mod( 'charvi_vimeo_link', '#' );
	$twitter_link_text		= get_theme_mod( 'charvi_twitter_link_text', esc_html__('Tweet On Twitter', 'charvi') );
	$pinterest_link_text	= get_theme_mod( 'charvi_pinterest_link_text', esc_html__('Pin It', 'charvi') );
	$facebook_link_text		= get_theme_mod( 'charvi_facebook_link_text', esc_html__('Like On Facebook', 'charvi') );
	$googleplus_link_text	= get_theme_mod( 'charvi_googleplus_link_text', esc_html__('Share On Google+', 'charvi') );
	$linkedin_link_text		= get_theme_mod( 'charvi_linkedin_link_text', esc_html__('Connect On Linkedin', 'charvi') );
	$youtube_link_text		= get_theme_mod( 'charvi_youtube_link_text', esc_html__('Watch On Youtube', 'charvi') );
	$soundcloud_link_text	= get_theme_mod( 'charvi_soundcloud_link_text', esc_html__('Listen On Soundcloud', 'charvi') );
	$instagram_link_text	= get_theme_mod( 'charvi_instagram_link_text', esc_html__('Follow On Instagram', 'charvi') );
	$vimeo_link_text		= get_theme_mod( 'charvi_vimeo_link_text', esc_html__('Watch On Vimeo', 'charvi') );
	?>
	<div class="dtr-social-band clearfix">
		<ul class="dtr-social-band-list">
			<?php if ( 'show' == get_theme_mod( 'charvi_twitter_band_enable', 'show' ) ) { ?>
			<li> <a href="<?php echo esc_url( $twitter_link ); ?>" target="_blank" class="dtr-social-band-link dtr-twitter-band"><span><?php echo esc_attr( $twitter_link_text ); ?></span></a> </li>
			<?php } ?>
			<?php if ( 'show' == get_theme_mod( 'charvi_pinterest_band_enable', 'show' ) ) { ?>
			<li> <a href="<?php echo esc_url( $pinterest_link ); ?>" target="_blank" class="dtr-social-band-link dtr-pinterest-band"><span><?php echo esc_attr( $pinterest_link_text ); ?></span></a> </li>
			<?php } ?>
			<?php if ( 'show' == get_theme_mod( 'charvi_facebook_band_enable', 'show' ) ) { ?>
			<li> <a href="<?php echo esc_url( $facebook_link ); ?>" target="_blank" class="dtr-social-band-link dtr-facebook-band"><span><?php echo esc_attr( $facebook_link_text ); ?></span></a> </li>
			<?php } ?>
			<?php if ( 'show' == get_theme_mod( 'charvi_googleplus_band_enable', 'show' ) ) { ?>
			<li> <a href="<?php echo esc_url( $googleplus_link ); ?>" target="_blank" class="dtr-social-band-link dtr-googleplus-band"><span><?php echo esc_attr( $googleplus_link_text ); ?></span></a> </li>
			<?php } ?>
			<?php if ( 'show' == get_theme_mod( 'charvi_linkedin_band_enable', 'show' ) ) { ?>
			<li> <a href="<?php echo esc_url( $linkedin_link ); ?>" target="_blank" class="dtr-social-band-link dtr-linkedin-band"><span><?php echo esc_attr( $linkedin_link_text ); ?></span></a> </li>
			<?php } ?>
			<?php if ( 'show' == get_theme_mod( 'charvi_youtube_band_enable', 'show' ) ) { ?>
			<li> <a href="<?php echo esc_url( $youtube_link ); ?>" target="_blank" class="dtr-social-band-link dtr-youtube-band"><span><?php echo esc_attr( $youtube_link_text ); ?></span></a> </li>
			<?php } ?>
			<?php if ( 'show' == get_theme_mod( 'charvi_soundcloud_band_enable', 'show' ) ) { ?>
			<li> <a href="<?php echo esc_url( $soundcloud_link ); ?>" target="_blank" class="dtr-social-band-link dtr-soundcloud-band"><span><?php echo esc_attr( $soundcloud_link_text ); ?></span></a> </li>
			<?php } ?>
			<?php if ( 'show' == get_theme_mod( 'charvi_instagram_band_enable', 'show' ) ) { ?>
			<li> <a href="<?php echo esc_url( $instagram_link ); ?>" target="_blank" class="dtr-social-band-link dtr-instagram-band"><span><?php echo esc_attr( $instagram_link_text ); ?></span></a> </li>
			<?php } ?>
			<?php if ( 'show' == get_theme_mod( 'charvi_vimeo_band_enable', 'show' ) ) { ?>
			<li> <a href="<?php echo esc_url( $vimeo_link ); ?>" target="_blank" class="dtr-social-band dtr-vimeo-band"><span><?php echo esc_attr( $vimeo_link_text ); ?></span></a> </li>
			<?php } ?>
		</ul>
	</div>
<?php	}
} // charvi_social_band

// instagram
require_once( CHARVI_DIR .'/includes/widgets/instagram-fetch-feed.php' );

/**
 * Register widgets
 */
function charvi_register_widgets() {
  $charvi_widgets = array(
    'social'        => 'charvi_social_widget',
	'instagram'     => 'charvi_instagram_widget',
	'about'     	=> 'charvi_about_widget',
	'about-simple'  => 'charvi_simple_about_widget',
	'recentposts'   => 'charvi_recentposts_widget',
  );
  foreach ( $charvi_widgets as $key => $value ) {
	require_once( CHARVI_DIR . 'includes/widgets/' . sanitize_key( $key ) . '.php' );
    register_widget( $value );
  }
} // charvi_register_widgets
add_action( 'widgets_init', 'charvi_register_widgets' );