<?php
/**
 * Include and setup custom metaboxes and fields.
 */
add_action( 'cmb2_admin_init', 'charvi_metaboxes' );
/**
 * Hook in and add a metabox
 */
function charvi_metaboxes() {
	
	// Prefix
	$prefix = '_charvi_';
	
	// Display metaboxes according to post format
	add_action( 'admin_print_scripts', 'charvi_display_metaboxes', 1000 );
    function charvi_display_metaboxes() {
    	if ( get_post_type() == "post" ) :
        ?>
	<script type="text/javascript">
		jQuery( document ).ready( function($) {
	
		var	$pfaudio = $('#format-post-audio').hide(),
			$pflink = $('#format-post-link').hide(),
			$pfquote = $('#format-post-quote').hide(),
			$pfvideo = $('#format-post-video').hide(),
			$pfgallery = $('#format-post-gallery').hide(),
			$post_format = $('input[name="post_format"]');
	
		$post_format.each(function() {
			var $this = $(this);
			if( $this.is(':checked') )
				change_post_format( $this.val() );
		});
	
		$post_format.change(function() {
			change_post_format( $(this).val() );
		});
	
		function change_post_format( val ) {
			$pfaudio.hide();
			$pflink.hide();
			$pfquote.hide();
			$pfvideo.hide();
			$pfgallery.hide();
			
			if( val === 'audio' ) {
				$pfaudio.show();
			} else if( val === 'link' ) {
				$pflink.show();
			} else if( val === 'quote' ) {
				$pfquote.show();
			} else if( val === 'gallery' ) {
				$pfgallery.show();
			} else if( val === 'video' ) {
				$pfvideo.show();
			}
		}
	});
     </script>
	<?php
    	endif;
	 }
	
	/**
	 * Testimonial Settings
	 */
	$charvi_testimonial_metabox = new_cmb2_box( array(
		'id'            => $prefix . 'testimonial-settings-metabox',
		'title'         => esc_html__( 'Testimonial Settings', 'charvi' ),
		'object_types'  => array( 'dtr_testimonial' ), // Post type
		'context'    => 'normal',
		'priority'   => 'high',
	) );
	
	$charvi_testimonial_metabox->add_field( array(
		'desc'  =>  wp_kses( __( 'Title is used as ID to recognize respective promobox. It will not be displayed frontend anywhere.<br>ID for Promobox is <strong> Slug </strong> of Post === Title as viewed in permalink<br><br>Shortcode to Display Promobox :<br><br>[dtr_testimonial id="ID"]', 'charvi'), array( 'br' => array(), 'strong' => array(), 'i' => array(), ) ),
		'id'   	=> $prefix . 'promobox_testimonial_shorthand',
		'type' 	=> 'title',
	) );
	
	$charvi_testimonial_metabox->add_field( array(
		'name'	=> esc_html__( 'Testimonial Tagline', 'charvi' ),
		'id'   	=> $prefix . 'testimonial_tagline',
		'type'	=> 'text',
	) );
	
	$charvi_testimonial_metabox->add_field( array(
		'name'	=> esc_html__( 'Client Name', 'charvi' ),
		'id'   	=> $prefix . 'testimonial_client_name',
		'type'	=> 'text',
	) );
	
	$charvi_testimonial_metabox->add_field( array(
		'name'	=> esc_html__( 'Client Designation', 'charvi' ),
		'id'   	=> $prefix . 'testimonial_client_designation',
		'type'	=> 'text',
	) );
	
	// Page Layout
	$page_layout = array(
		'' 					=> esc_html__( 'Default', 'charvi' ),
		'dtr-fullwidth'		=> esc_html__( 'No Sidebar', 'charvi' ),
		'dtr-right-sidebar'	=> esc_html__( 'Right Sidebar', 'charvi' ),
		'dtr-left-sidebar' 	=> esc_html__( 'Left Sidebar', 'charvi' ),
	);
	
	// Page Header Background image styles
	$page_header_bg_image_style = array(
		'repeat'	=> esc_html__( 'Repeat', 'charvi' ),
		'stretched'	=> esc_html__( 'Stretched', 'charvi' ),
		'fixed'		=> esc_html__( 'Fixed', 'charvi' ),
	);

	/**
	 * Page Settings
	 */
	$charvi_page_metabox = new_cmb2_box( array(
		'id'            => $prefix . 'page-settings-metabox',
		'title'         => esc_html__( 'Page Settings', 'charvi' ),
		'object_types'  => array( 'page', 'post' ), // Post type
		'context'    => 'normal',
		'priority'   => 'high',
	) );

	$charvi_page_metabox->add_field( array(
		'id'   		=> $prefix . 'page_layout_meta',
		'name' 		=> esc_html__( 'Sidebar Position', 'charvi' ),
		'type' 		=> 'select',
		'options'	=> $page_layout,
	) );
	
	/**
	 * Page Header
	 */
	$charvi_page_header_metabox = new_cmb2_box( array(
		'id'            => $prefix . 'page-header-metabox',
		'title'         => esc_html__( 'Page Title Section Style', 'charvi' ),
		'object_types'	=> array( 'page', 'post', 'dtr_testimonial' ), // Post type
		'context'    	=> 'normal',
		'priority'   	=> 'high',
	) );
	
	$charvi_page_header_metabox->add_field( array(
		'name' => esc_html__( 'Page Title Background Image - Upload or enter URL', 'charvi' ),
		'id'   =>  $prefix . 'page_header_bg_image',
		'type' => 'file',
	) );

	$charvi_page_header_metabox->add_field( array(
		'id'   		=> $prefix . 'page_header_bg_image_style',
		'name' 		=> esc_html__( 'Page Title Background Style', 'charvi' ),
		'type' 		=> 'select',
		'options'	=> $page_header_bg_image_style,
	) );
	
	$charvi_page_header_metabox->add_field( array(
		'name' => esc_html__( 'Overlay Opacity', 'charvi' ),
		'id'   => $prefix . 'page_header_bg_image_overlay',
		'desc' => wp_kses( __( 'Useful if light colored image, to improve text visibility. <br> Give it in  decimal like:  <br> .1 <br> .3<br>If overlay assigned via theme options, give - 0 - if need image as such.', 'charvi' ), array( 'br' => array(), ) ),
		'type'  => 'text',
	) );
	
	/**
	 * Post formats
	 */
	// Gallery Post Format
	$charvi_gallery_pf_metabox = new_cmb2_box( array(
		'id'            => 'format-post-gallery',
		'title'      	=> esc_html__( 'Upload Gallery Images', 'charvi' ),
		'object_types'	=> array( 'post', ), // Post type
		'context'    	=> 'normal',
		'priority'   	=> 'high',
	) );
	
	$charvi_gallery_pf_metabox->add_field( array(
		'id'   	=> $prefix . 'pf_gallery',
		'type' => 'file_list',
		'text' => array(
		//'add_upload_files_text' => 'Replacement', // default: "Add or Upload Files"
//		'remove_image_text' => 'Replacement', // default: "Remove Image"
//		'file_text' => 'Replacement', // default: "File:"
//		'file_download_text' => 'Replacement', // default: "Download"
//		'remove_text' => 'Replacement', // default: "Remove"
	),
	
	) );
	
	
	// Audio Post Format
	$charvi_audio_pf_metabox = new_cmb2_box( array(
		'id'            => 'format-post-audio',
		'title'         => esc_html__( 'Audio Embed Code', 'charvi' ),
		'object_types'	=> array( 'post', ), // Post type
		'context'    	=> 'normal',
		'priority'   	=> 'high',
	) );
	
	$charvi_audio_pf_metabox->add_field( array(
		'id'   => $prefix . 'pf_audio_embed',
		'type' 	=> 'textarea_code',
	) );
	
	// Video Post Format
	$charvi_video_pf_metabox = new_cmb2_box( array(
		'id'            => 'format-post-video',
		'title'         => esc_html__( 'Video Embed Code', 'charvi' ),
		'object_types'	=> array( 'post', ), // Post type
		'context'    	=> 'normal',
		'priority'   	=> 'high',
	) );
	
	$charvi_video_pf_metabox->add_field( array(
		'id'   => $prefix . 'pf_video_embed',
		'type' 	=> 'textarea_code',
	) );
	
	// Quote Post Format
	$charvi_quote_pf_metabox = new_cmb2_box( array(
		'id'            => 'format-post-quote',
		'title'      	=> esc_html__( 'Quote', 'charvi' ),
		'object_types'	=> array( 'post', ), // Post type
		'context'    	=> 'normal',
		'priority'   	=> 'high',
	) );
	
	$charvi_quote_pf_metabox->add_field( array(
		'name'	=> esc_html__( 'Quote text', 'charvi' ),
		'id'   	=> $prefix . 'pf_quote',
		'type'	=> 'textarea',
	) );
	
	$charvi_quote_pf_metabox->add_field( array(
		'name'	=> esc_html__( 'Quote Source', 'charvi' ),
		'id'   	=> $prefix . 'pf_quote_source',
		'type'	=> 'text',
	) );
	
	// Link Post Format
	$charvi_link_pf_metabox = new_cmb2_box( array(
		'id'            => 'format-post-link',
		'title'      	=> esc_html__( 'Link Text and URL', 'charvi' ),
		'object_types'	=> array( 'post', ), // Post type
		'context'    	=> 'normal',
		'priority'   	=> 'high',
	) );
	
	$charvi_link_pf_metabox->add_field( array(
		'name'	=> esc_html__( 'Link text', 'charvi' ),
		'id'   	=> $prefix . 'pf_link_text',
		'type'	=> 'text',
	) );
	
	$charvi_link_pf_metabox->add_field( array(
		'name'	=> esc_html__( 'Link URL', 'charvi' ),
		'id'   	=> $prefix . 'pf_link_url',
		'type'	=> 'text',
	) );

} // charvi_metaboxes