<?php
/**
 * About Widget - Variation
 */

// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}
// class starts
if ( ! class_exists( 'CHARVI_Simple_About_Widget' ) ) {
	class CHARVI_Simple_About_Widget extends WP_Widget {
	
		/**
		 * Register widget
		 */
		public function __construct() {
			$widget_ops = array(
      			'classname' => 'charvi_simple_about_widget',
      			'description' => esc_html__( 'Display About Information', 'charvi' ),
    		);
    		parent::__construct( 'charvi_simple_about_widget', esc_html__( 'Custom: About Variation', 'charvi' ), $widget_ops );
			add_action( 'load-widgets.php', array( $this, 'admin_setup' ), 100 );
		}
		
		/**
		 * Enqueue media scripts
		 */
		public function admin_setup() {
			wp_enqueue_media();
		}

		/**
	 	 * Output the content of the widget
		 */
		public function widget( $args, $instance ) {

			// vars
			$output 		= '';
			$title      	= isset( $instance['title'] ) ? apply_filters( 'widget_title', $instance['title'] ) : '';
			$description	= isset( $instance['description'] ) ? $instance['description'] : '';
			$wpautop     	= isset( $instance['wpautop'] ) ? $instance['wpautop'] : '';
			$image       	= isset( $instance['image'] ) ? esc_url( $instance['image'] ) : '';
	
			// Before widget
			$output .= $args['before_widget'];

			// Widget title
			if ( $title ) {
				$output .= $args['before_title'];
					$output .= $title;
				$output .= $args['after_title'];
			}
			
			// output starts
			$output .= '<div class="dtr-simple-about-widget clearfix">';

				// image
				if ( $image ) :
					$output .= '<div class="dtr-simple-about-widget-img">';
						$output .= '<img src="'. $image .'" alt="'. esc_attr( $title ) .'"/>';
					$output .= '</div>';
				endif;

				// description
				$output .= '<div class="dtr-simple-about-widget-desc">';
					if ( 'on' == $wpautop ) {
						$output .= wpautop( wp_kses_post( $description ) );
					} else {
						$output .= wp_kses_post( $description );
					}
				$output .= '</div>';

			$output .= '</div>';
			// output ends

			// After widget
			$output .= $args['after_widget'];

			// output echo
			echo $output;
		
		} 

		/**
		 *  Update the information in the WordPress database
		 */	
		 
		public function update( $new_instance, $old_instance ) {
			$instance                 	= $old_instance;
			$instance['title']      	= strip_tags( $new_instance['title'] );
			$instance['description']	= wp_kses_post( $new_instance['description'] );
			$instance['wpautop']     	= ! empty( $new_instance['wpautop'] ) ? 'on' : '';
			$instance['image']       	= strip_tags( $new_instance['image'] );

			/**
			 * Register strings for WPML translation
			 */
			if ( function_exists ( 'icl_register_string' ) ){
				icl_register_string('About Widget', 'Description', $instance['description']);
				
			} // icl_register_string
				
			return $instance;
		} 

		/**
		 * Add form fields to the widget which will be displayed in the WordPress admin area.
		 */
		public function form( $instance ) {
			
			extract( wp_parse_args( $instance, array(
				'title'         => '',
				'description'	=> '',
				'wpautop'     	=> '',
				'image'       	=> '',
			) ) ); ?>
<p>
	<label for="<?php echo esc_attr( $this->get_field_id( 'title' ) ); ?>">
		<?php esc_attr_e( 'Title', 'charvi' ); ?>
	</label>
	<input class="widefat" name="<?php echo esc_attr( $this->get_field_name( 'title' ) ); ?>" type="text" value="<?php echo esc_attr( $title ); ?>" />
</p>
<p>
	<label for="<?php echo esc_attr( $this->get_field_id( 'description' ) ); ?>">
		<?php esc_attr_e( 'Description', 'charvi' ); ?>
	</label>
	<textarea class="widefat" rows="6" cols="20" id="<?php echo esc_attr( $this->get_field_id( 'description' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'description' ) ); ?>"><?php if ( ! empty( $instance['description'] ) ) {  echo wp_kses_post( $instance['description'] ); } ?>
</textarea>
</p>
<p>
	<input class="widefat" id="<?php echo esc_attr( $this->get_field_id( 'wpautop' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'wpautop' ) ); ?>" type="checkbox" <?php checked( 'on', $wpautop, true ); ?> />
	<label for="<?php echo esc_attr( $this->get_field_id( 'wpautop' ) ); ?>">
		<?php esc_html_e( 'Automatically add paragraphs', 'charvi' ); ?>
	</label>
</p>
<p>
	<label for="<?php echo esc_attr( $this->get_field_id( 'image' ) ); ?>">
			<?php esc_html_e( 'Image URL', 'charvi' ); ?>
	</label>
	<input class="widefat" name="<?php echo esc_attr( $this->get_field_name( 'image' ) ); ?>" type="text" value="<?php echo esc_attr( $image ); ?>" />
</p>
<?php
		} 
	// class ends
	}
}
register_widget( 'CHARVI_Simple_About_Widget' );