<?php
namespace CharviAddons\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Utils;
use Elementor\Control_Media;

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

/**
 * Packagebox Widget
 */
class Charvi_Packagebox extends Widget_Base {

	/**
	 * Retrieve widget name.
	 * @access public
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'packagebox';
	}

	/**
	 * Retrieve widget title.
	 * @access public
	 * @return string Widget title.
	 */
	public function get_title() {
		return __( 'Packagebox', 'charvi' );
	}

	/**
	 * Retrieve widget icon.
	 * @access public
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-favorite';
	}

	/**
	 * Retrieve the list of categories widget belongs to.
	 * Used to determine where to display the widget in the editor.
	 * @access public
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return array('dtr-element');
	}
	

	/**
	 * Register widget controls.
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 * @access protected
	 */
	protected function _register_controls() {
		// content control starts
		// image
		$this->start_controls_section(
			'section_packagebox',
			[
				'label' => __( 'Packagebox', 'charvi' ),
			]
		);

		$this->add_control(
			'image',
			[
				'label' => __( 'Choose Image', 'charvi' ),
				'type' => Controls_Manager::MEDIA,
				'default' => [
					'url' => Utils::get_placeholder_image_src(),
				],
			]
		);
		
		// title
		$this->add_control(
			'title_text',
			[
				'label' => __( 'Title', 'charvi' ),
				'type' => Controls_Manager::TEXT,
				'default' => __( 'This is the heading', 'charvi' ),
				'placeholder' => __( 'Your Title', 'charvi' ),
				'label_block' => true,
			]
		);
		
		// tagline
		$this->add_control(
			'packagebox_tagline',
			[
				'label' => __( 'Tagline', 'charvi' ),
				'type' => Controls_Manager::TEXT,
				'default' => __( 'Freebie', 'charvi' ),
				'placeholder' => __( 'Your Tagline', 'charvi' ),
				'label_block' => true,
			]
		);
		// description
		$this->add_control(
			'description_text',
			[
				'label' => __( 'Description', 'charvi' ),
				'type' => Controls_Manager::TEXTAREA,
				'default' => __( 'Click edit button to change this text. Lorem ipsum dolor sit amet, consectetur adipiscing elit. Ut elit tellus, luctus nec ullamcorper mattis, pulvinar dapibus leo.', 'charvi' ),
				'placeholder' => __( 'Your Description', 'charvi' ),
				'title' => __( 'Description text here', 'charvi' ),
				'separator' => 'none',
				'rows' => 10,
				'show_label' => true,
			]
		);
		
		// button
		$this->add_control(
			'packagebox_btn_text',
			[
				'label' => __( 'Button Text', 'charvi' ),
				'type' => Controls_Manager::TEXT,
				'default' => __( 'ACCESS', 'charvi' ),
				'description' => __('Leave blank if need to hide button. Visible in caption only if title or subtitle provided.', 'charvi'),
				'placeholder' => __( 'Your Button Text', 'charvi' ),
				'label_block' => true,
			]
		);
				
		$this->add_control(
			'wrap_in_link',
			[
				'label' => __( 'Wrap Packagebox in Link', 'charvi' ),
				'type' => Controls_Manager::SELECT,
				'default' => 'hide',
				'options' => [
					'hide' => __( 'No', 'charvi' ),
					'show' => __( 'Yes', 'charvi' ),
				],
			]
		);
		
		$this->add_control(
			'packagebox_btn_link',
			[
				'label' => __( 'Link', 'charvi' ),
				'type' => Controls_Manager::URL,
				'placeholder' => 'http://your-link.com',
				'description' => __('Leave blank if link not required', 'charvi'),
				'default' => [
					'url' => '#',
				],
			]
		);
		
		$this->add_control(
			'view',
			[
				'label' => __( 'View', 'charvi' ),
				'type' => Controls_Manager::HIDDEN,
				'default' => 'traditional',
			]
		);
		$this->end_controls_section();
		// content control ends
		
		// style control starts
		$this->start_controls_section(
			'section_style_content',
			[
				'label' => __( 'Content', 'charvi' ),
				'tab'   => Controls_Manager::TAB_STYLE,
			]
		);
		// title
		$this->add_control(
			'heading_title',
			[
				'label' => __( 'Title', 'charvi' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		
		$this->add_control(
			'title_color',
			[
				'label' => __( 'Color', 'charvi' ),
				'type' => Controls_Manager::COLOR,
				'default' => '',
				'selectors' => [
					'{{WRAPPER}} .dtr-packagebox-title' => 'color: {{VALUE}};',
				],
			]
		);
		// tagline
		$this->add_control(
			'heading_tagline',
			[
				'label' => __( 'Tagline', 'charvi' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		
		$this->add_control(
			'taglinebg_color',
			[
				'label' => __( 'Background Color', 'charvi' ),
				'default' => '',
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} span.dtr-packagebox-tagline' => 'background-color: {{VALUE}};',
				],
			]
		);
		
		$this->add_control(
			'tagline_color',
			[
				'label' => __( 'Color', 'charvi' ),
				'type' => Controls_Manager::COLOR,
				'default' => '',
				'selectors' => [
					'{{WRAPPER}} .dtr-packagebox-tagline' => 'color: {{VALUE}};',
				],
			]
		);

		// description
		$this->add_control(
			'heading_description',
			[
				'label' => __( 'Description', 'charvi' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		
		$this->add_control(
			'contentbg_color',
			[
				'label' => __( 'Background Color', 'charvi' ),
				'type' => Controls_Manager::COLOR,
				'default' => '',
				'selectors' => [
					'{{WRAPPER}} .dtr-packagebox-content' => 'background-color: {{VALUE}};',
				],
			]
		);
		
		$this->add_control(
			'description_color',
			[
				'label' => __( 'Color', 'charvi' ),
				'type' => Controls_Manager::COLOR,
				'default' => '',
				'selectors' => [
					'{{WRAPPER}} .packagebox-description' => 'color: {{VALUE}};',
				],
			]
		);
		
		// button
		$this->add_control(
			'packagebox_button_control',
			[
				'label' => __( 'Button', 'charvi' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		
		$this->add_control(
			'packagebox_button_bg',
			[
				'label' => __( 'Background Color', 'charvi' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} a.dtr-packagebox-btn, {{WRAPPER}} .dtr-packagebox-btn' => 'background-color: {{VALUE}};',
				],
			]
		);
		
		$this->add_control(
			'packagebox_button_border_color',
			[
				'label' => __( 'Border Color', 'charvi' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} a.dtr-packagebox-btn, {{WRAPPER}} .dtr-packagebox-btn' => 'border-color: {{VALUE}};',
				],
			]
		);
			
		$this->add_control(
			'packagebox_button_color',
			[
				'label' => __( 'Text Color', 'charvi' ),
				'type' => Controls_Manager::COLOR,
				'default' => '',
				'selectors' => [
					'{{WRAPPER}} a.dtr-packagebox-btn, {{WRAPPER}} .dtr-packagebox-btn' => 'color: {{VALUE}};',
				],
			]
		);
		
		$this->end_controls_section();
		// style control ends
	}

	/**
	 * Render widget output on the frontend.
	 * Written in PHP and used to generate the final HTML.
	 * @access protected
	 */
	protected function render() {
		$settings = $this->get_settings();
		$has_content = ! empty( $settings['title_text'] ) || ! empty( $settings['description_text'] );
		// output starts
		$html = '<div class="dtr-packagebox">';
		
		if ( ! empty( $settings['packagebox_btn_link']['url'] ) && 'show' === $settings['wrap_in_link'] ) {
			$link = esc_url( $settings['packagebox_btn_link']['url'] );
			$target = $settings['packagebox_btn_link']['is_external'] ? 'target="_blank"' : '';
			$nofollow = $settings['packagebox_btn_link']['nofollow'] ? 'rel="nofollow"' : '';
			$html .= sprintf( '<a class="dtr-link-wrap" href="%1$s" %2$s %3$s></a>', $link, $target, $nofollow );
		}	
		
		// image
		if ( ! empty( $settings['image']['url'] ) ) {
			$this->add_render_attribute( 'image', 'src', $settings['image']['url'] );
			$this->add_render_attribute( 'image', 'alt', Control_Media::get_image_alt( $settings['image'] ) );
			$this->add_render_attribute( 'image', 'title', Control_Media::get_image_title( $settings['image'] ) );
			$image_html = '<img ' . $this->get_render_attribute_string( 'image' ) . '>';
			$html .= '<figure class="dtr-packagebox-img">' . $image_html . '</figure>';
		}
		// tagline
		if ( ! empty( $settings['packagebox_tagline'] ) ) {
			$html .= sprintf( '<span class="dtr-packagebox-tagline">%s</span>', $settings['packagebox_tagline'] );
		}
			
		// content
		if ( $has_content ) {
			$html .= '<div class="dtr-packagebox-content">';

			if ( ! empty( $settings['title_text'] ) ) {
				$html .= sprintf( '<h5 class="dtr-packagebox-title">%s</h5>', $settings['title_text'] );
			}

			if ( ! empty( $settings['description_text'] ) ) {
				$html .= sprintf( '<p class="packagebox-description">%s</p>', $settings['description_text'] );
			}
			
			if ( ! empty( $settings['packagebox_btn_text'] ) ) {
				$title_html = $settings['packagebox_btn_text'];
				if ( ! empty( $settings['packagebox_btn_link']['url'] ) ) {
					$link = esc_url( $settings['packagebox_btn_link']['url'] );
				} 
				$target = $settings['packagebox_btn_link']['is_external'] ? 'target="_blank"' : '';
				$nofollow = $settings['packagebox_btn_link']['nofollow'] ? 'rel="nofollow"' : '';
				$html .= sprintf( '<a class="themebtn dtr-packagebox-btn" href="%1$s" %2$s %3$s>' . $title_html . '</a>', $link, $target, $nofollow );
			}

			$html .= '</div>';
		}
		
		$html .= '</div>';
		echo $html;
	}

	/**
	 * Render widget output in the editor.
	 * Written as a Backbone JavaScript template and used to generate the live preview.
	 * @access protected
	 */
	protected function _content_template() {
		?>
		<#
		var html = '<div class="dtr-packagebox">';
		switch ( settings.wrap_in_link ) {
			case 'show' :
				html += '<a class="dtr-link-wrap" style="position: relative; display: none;"></a>';
				break;

			case 'hide' :
			default:
				html += '<a class="dtr-link-wrap" style="position: relative; display: none;"></a>';
				break;
		}
		if ( settings.image.url ) {
			var imageHtml = '<img src="' + settings.image.url + '" class="elementor-animation-' + settings.hover_animation + '" />';
			html += '<figure class="dtr-packagebox-img">' + imageHtml + '</figure>';
		}
		
		if ( settings.packagebox_tagline ) {
			html += '<span class="dtr-packagebox-tagline">' + settings.packagebox_tagline + '</span>';
		}

		var hasContent = !! ( settings.title_text || settings.description_text );

		if ( hasContent ) {
			html += '<div class="dtr-packagebox-content">';

			if ( settings.title_text ) {
				var title_html = settings.title_text;
				html += '<h5 class="dtr-packagebox-title">' + title_html + '</h5>';
			}

			if ( settings.description_text ) {
				html += '<p class="packagebox-description">' + settings.description_text + '</p>';
			}
			if ( settings.packagebox_btn_text ) {
					html += '<a class="dtr-packagebox-btn themebtn">' + settings.packagebox_btn_text + '</a>';
				}
			html += '</div>';
		}
		html += '</div>';
		print( html );
		#>
		<?php
	}
}