<?php
namespace CharviAddons\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Utils;
use Elementor\Control_Media;

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

/**
 * Testimonial Carousel Widget
 */
class Charvi_Testimonial_Carousel extends Widget_Base {

	/**
	 * Retrieve widget name.
	 * @access public
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'testimonialcarousel';
	}

	/**
	 * Retrieve widget title.
	 * @access public
	 * @return string Widget title.
	 */
	public function get_title() {
		return __( 'Testimonial Carousel', 'charvi' );
	}

	/**
	 * Retrieve widget icon.
	 * @access public
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-favorite';
	}

	/**
	 * Retrieve the list of categories widget belongs to.
	 * Used to determine where to display the widget in the editor.
	 * @access public
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return array('dtr-element');
	}

	/**
	 * Register widget controls.
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 * @access protected
	 */
	protected function _register_controls() {
		
		// content control starts
		$this->start_controls_section(
			'section_testimonial_content',
			[
				'label' => __( 'Testimonial Carousel', 'charvi' ),
			]
		);
		
		$this->add_control(
			'testimonial_carousel_info',
			[
				'label' => __( 'Save and refresh for testimonial to be visible in editor.', 'charvi' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		
		$this->add_control(
			'post_limit',
			[
				'label' => __( 'Number of posts to show in carousel', 'charvi' ),
				'type' => Controls_Manager::NUMBER,
				'default' => 2,
				'min' => 2,
				'step' => 1,
			]
		);
		
		$this->add_control(
			'post_orderby',
			[
				'label' => __( 'Sort Testimonials By', 'charvi' ),
				'type' => Controls_Manager::SELECT,
				'default' => 'date',
				'options' => [
					'date' 	=> __( 'Date', 'charvi' ),
					'rand' 	=> __( 'Random', 'charvi' ),
					'title'	=> __( 'Title', 'charvi' ),
				],
			]
		);
		
		$this->add_control(
			'post_order',
			[
				'label' => __( 'Arrange Sorted Testimonials', 'charvi' ),
				'type' => Controls_Manager::SELECT,
				'default' => 'DESC',
				'options' => [
					'DESC'	=> __( 'Descending', 'charvi' ),
					'ASC'  	=> __( 'Ascending', 'charvi' ),
				],
			]
		);
		
		$this->end_controls_section();
		// content control ends

		// style control starts
		$this->start_controls_section(
			'section_style_content',
			[
				'label' => __( 'Content', 'charvi' ),
				'tab'   => Controls_Manager::TAB_STYLE,
			]
		);

		$this->add_control(
			'about_tagline_color',
			[
				'label' => __( 'Quote Icon Color', 'charvi' ),
				'default' => '',
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .dtr-testimonial::before' => 'color: {{VALUE}};',
				],
			]
		);
		
		$this->end_controls_section();
		// style control ends
		
	}

	/**
	 * Render widget output on the frontend.
	 * Written in PHP and used to generate the final HTML.
	 * @access protected
	 */
	 protected function render() {
		$settings = $this->get_settings(); 
		echo do_shortcode('[dtr_testimonial_carousel limit="' . $settings['post_limit'] . '" orderby="' . $settings['post_orderby'] . '" order="' . $settings['post_order'] . '"]');
		
	}
	
	/**
	 * Render widget output in the editor.
	 * Written as a Backbone JavaScript template and used to generate the live preview.
	 * @access protected
	 */
	protected function _content_template() { }
}